@@ -32,20 +32,13 @@ class FFmpegError(Exception):
                 if re.search(pattern, message, flags=re.IGNORECASE) is not None:
                     return subclass(message, arguments)
 
-        return FFmpegError(message, arguments)
+        return cls(message, arguments)
 
 
 class FFmpegAlreadyExecuted(FFmpegError):
     "Represents FFmpeg is being executed"
 
 
-class FFmpegFileExists(FFmpegError):
-    "Represents the output file already exists. You can overwrite it using the `-y` option"
-    _patterns = [
-        r"already exists",
-    ]
-
-
 class FFmpegFileNotFound(FFmpegError):
     "Represents an input file was not found"
     _patterns = [
@@ -69,5 +62,7 @@ class FFmpegUnsupportedCodec(FFmpegError):
     "Represents FFmpeg attempted to use an unsupported codec"
     _patterns = [
         r"unknown encoder",
+        r"encoder not found",
         r"unknown decoder",
+        r"decoder not found",
     ]
