@@ -9,49 +9,43 @@ from ffmpeg import types
 
 
 class FFmpegProtocol(Protocol):
-    def __init__(self, executable: str = "ffmpeg"):
-        ...
+    def __init__(self, executable: str = "ffmpeg"): ...
 
-    def option(self, key: str, value: Optional[types.Option] = None) -> Self:
-        ...
+    @property
+    def arguments(self) -> list[str]: ...
+
+    def option(self, key: str, value: Optional[types.Option] = None) -> Self: ...
 
     def input(
         self,
         url: Union[str, os.PathLike],
         options: Optional[dict[str, Optional[types.Option]]] = None,
         **kwargs: Optional[types.Option],
-    ) -> Self:
-        ...
+    ) -> Self: ...
 
     def output(
         self,
         url: Union[str, os.PathLike],
         options: Optional[dict[str, Optional[types.Option]]] = None,
         **kwargs: Optional[types.Option],
-    ) -> Self:
-        ...
+    ) -> Self: ...
 
     @overload
     def execute(
         self,
         stream: Optional[types.Stream] = None,
-    ) -> bytes:
-        ...
+    ) -> bytes: ...
 
     @overload
     async def execute(
         self,
         stream: Optional[types.AsyncStream] = None,
-    ) -> bytes:
-        ...
+    ) -> bytes: ...
 
-    def terminate(self):
-        ...
+    def terminate(self): ...
 
     def on(
         self, event: str, f: Optional[types.Handler] = None
-    ) -> Union[types.Handler, Callable[[types.Handler], types.Handler]]:
-        ...
+    ) -> Union[types.Handler, Callable[[types.Handler], types.Handler]]: ...
 
-    def emit(self, event: str, *args: Any, **kwargs: Any) -> bool:
-        ...
+    def emit(self, event: str, *args: Any, **kwargs: Any) -> bool: ...
